@@ -18,8 +18,7 @@ class DecisionTreeEdgeLabelPrediction(SklearnEdgeLabelPredictionAdapter):
         max_features=None,
         max_leaf_nodes=None,
         min_impurity_decrease=0.,
-        min_impurity_split=None,
-        class_weight=None,
+        class_weight="balanced",
         ccp_alpha=0.0,
         edge_embedding_method: str = "Concatenate",
         use_edge_metrics: bool = False,
@@ -35,7 +34,6 @@ class DecisionTreeEdgeLabelPrediction(SklearnEdgeLabelPredictionAdapter):
         self._max_features = max_features
         self._max_leaf_nodes = max_leaf_nodes
         self._min_impurity_decrease = min_impurity_decrease
-        self._min_impurity_split = min_impurity_split
         self._random_state = random_state
         self._class_weight = class_weight
         self._ccp_alpha = ccp_alpha
@@ -51,7 +49,6 @@ class DecisionTreeEdgeLabelPrediction(SklearnEdgeLabelPredictionAdapter):
                 max_features=max_features,
                 max_leaf_nodes=max_leaf_nodes,
                 min_impurity_decrease=min_impurity_decrease,
-                min_impurity_split=min_impurity_split,
                 random_state=random_state,
                 class_weight=class_weight,
                 ccp_alpha=ccp_alpha,
@@ -82,7 +79,6 @@ class DecisionTreeEdgeLabelPrediction(SklearnEdgeLabelPredictionAdapter):
                 max_features=self._max_features,
                 max_leaf_nodes=self._max_leaf_nodes,
                 min_impurity_decrease=self._min_impurity_decrease,
-                min_impurity_split=self._min_impurity_split,
                 random_state=self._random_state,
                 class_weight=self._class_weight,
                 ccp_alpha=self._ccp_alpha,
