@@ -6,18 +6,20 @@ import numpy as np
 from scipy.sparse import coo_matrix
 from scipy.sparse.linalg import svds as sparse_svds
 from sklearn.utils.extmath import randomized_svd
-from userinput.utils import closest
-from embiggen.utils.abstract_models import AbstractEmbeddingModel, EmbeddingResult, format_list
+from userinput.utils import must_be_in_set
+from embiggen.embedders.ensmallen_embedders.ensmallen_embedder import EnsmallenEmbedder
+from embiggen.utils import EmbeddingResult
 
 
-class HOPEEnsmallen(AbstractEmbeddingModel):
+class HOPEEnsmallen(EnsmallenEmbedder):
     """Class implementing the HOPE algorithm."""
 
     def __init__(
         self,
         embedding_size: int = 100,
-        metric: str = "Jaccard",
+        metric: str = "Neighbours Intersection size",
         root_node_name: Optional[str] = None,
+        verbose: bool = False,
         enable_cache: bool = False
     ):
         """Create new HOPE method.
@@ -26,7 +28,7 @@ class HOPEEnsmallen(AbstractEmbeddingModel):
         --------------------------
         embedding_size: int = 100
             Dimension of the embedding.
-        metric: str = "Jaccard"
+        metric: str = "Neighbours Intersection size"
             The metric to use.
             You can either use:
             - Jaccard
@@ -39,19 +41,17 @@ class HOPEEnsmallen(AbstractEmbeddingModel):
             - Left Normalized Laplacian
             - Right Normalized Laplacian
             - Symmetric Normalized Laplacian
+            - Resnik
         root_node_name: Optional[str] = None
             Root node to use when the ancestors mode for
             the Jaccard index is selected.
+        verbose: bool = False
+            Whether to show loading bars.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
         """
-        if metric not in self.get_available_metrics():
-            raise ValueError(
-                f"The provided metric {metric} is not a supported "
-                f"metric. This you mean {closest(metric, self.get_available_metrics())}?"
-                f"The supported metrics are: {format_list(self.get_available_metrics())}."
-            )
+        metric = must_be_in_set(metric, self.get_available_metrics(), "metric")
         ancestral_metric = ("Ancestors Jaccard", "Ancestors size")
         if root_node_name is None and metric in ancestral_metric:
             raise ValueError(
@@ -67,6 +67,7 @@ class HOPEEnsmallen(AbstractEmbeddingModel):
 
         self._metric = metric
         self._root_node_name = root_node_name
+        self._verbose = verbose
 
         super().__init__(
             embedding_size=embedding_size,
@@ -75,13 +76,14 @@ class HOPEEnsmallen(AbstractEmbeddingModel):
 
     def parameters(self) -> Dict[str, Any]:
         """Returns parameters of the model."""
-        return {
+        return dict(
             **super().parameters(),
             **dict(
                 metric=self._metric,
+                verbose=self._verbose,
                 root_node_name=self._root_node_name
             )
-        }
+        )
 
     @classmethod
     def get_available_metrics(cls) -> List[str]:
@@ -105,7 +107,6 @@ class HOPEEnsmallen(AbstractEmbeddingModel):
         self,
         graph: Graph,
         return_dataframe: bool = True,
-        verbose: bool = True
     ) -> EmbeddingResult:
         """Return node embedding."""
         matrix = None
@@ -131,7 +132,7 @@ class HOPEEnsmallen(AbstractEmbeddingModel):
                     src_node_name=self._root_node_name,
                     compute_predecessors=True
                 ),
-                verbose=verbose
+                verbose=self._verbose
             )
         elif self._metric == "Ancestors size":
             matrix = graph.get_shared_ancestors_size_adjacency_matrix(
@@ -139,18 +140,13 @@ class HOPEEnsmallen(AbstractEmbeddingModel):
                     src_node_name=self._root_node_name,
                     compute_predecessors=True
                 ),
-                verbose=verbose
+                verbose=self._verbose
             )
         elif self._metric == "Adamic-Adar":
             edges, weights = graph.get_adamic_adar_coo_matrix()
         elif self._metric == "Adjacency":
             edges, weights = graph.get_directed_edge_node_ids(), np.ones(
                 graph.get_number_of_directed_edges())
-        else:
-            raise NotImplementedError(
-                f"The provided metric {self._metric} "
-                "is not currently supported."
-            )
 
         if matrix is None:
             matrix = coo_matrix(
@@ -191,27 +187,11 @@ class HOPEEnsmallen(AbstractEmbeddingModel):
             node_embeddings=[left_embedding, right_embedding]
         )
 
-    @classmethod
-    def task_name(cls) -> str:
-        return "Node Embedding"
-
     @classmethod
     def model_name(cls) -> str:
         """Returns name of the model."""
         return "HOPE"
 
-    @classmethod
-    def library_name(cls) -> str:
-        return "Ensmallen"
-
-    @classmethod
-    def requires_nodes_sorted_by_decreasing_node_degree(cls) -> bool:
-        return False
-
-    @classmethod
-    def is_topological(cls) -> bool:
-        return True
-
     @classmethod
     def can_use_edge_weights(cls) -> bool:
         """Returns whether the model can optionally use edge weights."""
