@@ -1,26 +1,34 @@
 """Module providing abstract Node2Vec implementation."""
-from typing import Optional, Union, Dict, Any
+from typing import Dict, Any
 from ensmallen import Graph
-import numpy as np
 import pandas as pd
+from userinput.utils import must_be_in_set
 from ensmallen import models
-from embiggen.utils.abstract_models import abstract_class, AbstractEmbeddingModel, EmbeddingResult
+from embiggen.utils.abstract_models import abstract_class
+from embiggen.embedders.ensmallen_embedders.ensmallen_embedder import EnsmallenEmbedder
+from embiggen.utils import EmbeddingResult
 
 
 @abstract_class
-class Node2VecEnsmallen(AbstractEmbeddingModel):
+class Node2VecEnsmallen(EnsmallenEmbedder):
     """Abstract class for Node2Vec algorithms."""
 
     MODELS = {
-        "cbow": models.CBOW,
-        "skipgram": models.SkipGram,
-        "walkletscbow": models.WalkletsCBOW,
-        "walkletsskipgram": models.WalkletsSkipGram,
+        "DeepWalk CBOW": models.CBOW,
+        "DeepWalk SkipGram": models.SkipGram,
+        "DeepWalk GloVe": models.GloVe,
+        "Node2Vec CBOW": models.CBOW,
+        "Node2Vec SkipGram": models.SkipGram,
+        "Node2Vec GloVe": models.GloVe,
+        "Walklets CBOW": models.WalkletsCBOW,
+        "Walklets SkipGram": models.WalkletsSkipGram,
+        "Walklets GloVe": models.WalkletsGloVe,
     }
 
     def __init__(
         self,
-        model_name: str,
+        embedding_size: int = 100,
+        random_state: int = 42,
         enable_cache: bool = False,
         **model_kwargs: Dict
     ):
@@ -28,77 +36,56 @@ class Node2VecEnsmallen(AbstractEmbeddingModel):
 
         Parameters
         --------------------------
-        model_name: str
-            The ensmallen graph embedding model to use.
-            Can either be the SkipGram, WalkletsSkipGram, CBOW and WalkletsCBOW models.
+        embedding_size: int = 100
+            Dimension of the embedding.
+        random_state: int = 42
+            The random state to reproduce the training sequence.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
         model_kwargs: Dict
             Further parameters to forward to the model.
         """
-        if model_name.lower() not in self.MODELS:
-            raise ValueError(
-                (
-                    "The provided model name {} is not supported. "
-                    "The supported models are `CBOW` and `SkipGram`."
-                ).format(model_name)
-            )
-
+        model_name = must_be_in_set(self.model_name(), self.MODELS.keys(), "model name")
         self._model_kwargs = model_kwargs
-
-        self._model = Node2VecEnsmallen.MODELS[model_name.lower()](**model_kwargs)
+        self._model = Node2VecEnsmallen.MODELS[model_name](**model_kwargs)
 
         super().__init__(
-            embedding_size=model_kwargs["embedding_size"],
+            embedding_size=embedding_size,
             enable_cache=enable_cache,
-            random_state=model_kwargs["random_state"]
+            random_state=random_state
         )
 
     @classmethod
     def smoke_test_parameters(cls) -> Dict[str, Any]:
         """Returns parameters for smoke test."""
         return dict(
-            **AbstractEmbeddingModel.smoke_test_parameters(),
+            **EnsmallenEmbedder.smoke_test_parameters(),
             epochs=1,
             window_size=1,
             walk_length=4,
             iterations=1,
             max_neighbours=10,
-            number_of_negative_samples=1
         )
 
     def parameters(self) -> Dict[str, Any]:
         """Returns parameters of the model."""
-        return {
+        return dict(
             **super().parameters(),
             **self._model_kwargs
-        }
-
-    @classmethod
-    def task_name(cls) -> str:
-        return "Node Embedding"
-
-    @classmethod
-    def library_name(cls) -> str:
-        return "Ensmallen"
-
-    def requires_nodes_sorted_by_decreasing_node_degree(self) -> bool:
-        return False
-
-    def is_topological(self) -> bool:
-        return True
+        )
 
     def _fit_transform(
         self,
         graph: Graph,
         return_dataframe: bool = True,
-        verbose: bool = True
     ) -> EmbeddingResult:
         """Return node embedding."""
         node_embeddings = self._model.fit_transform(graph)
-        if not isinstance(node_embeddings, list):
-            node_embeddings = [node_embeddings]
+
+        if "CBOW" in self.model_name():
+            node_embeddings = list(reversed(node_embeddings))
+
         if return_dataframe:
             node_names = graph.get_node_names()
             node_embeddings = [
@@ -151,4 +138,12 @@ class Node2VecEnsmallen(AbstractEmbeddingModel):
     @classmethod
     def is_stocastic(cls) -> bool:
         """Returns whether the model is stocastic and has therefore a random state."""
-        return True
\ No newline at end of file
+        return True
+
+    @classmethod
+    def requires_node_types(cls) -> bool:
+        return False
+
+    @classmethod
+    def requires_edge_types(cls) -> bool:
+        return False
\ No newline at end of file
